Overview
========

This project is a work in progress for a system dashboard tool that displays graphical dashboards in a terminal window with configurable data sources.


Installation
============

For now check it out and run the dashboard script in the scripts directory.

An example config file is provided in the root directory.

Dashboard
=========

More documentation TBD.

